@@ -49,6 +49,8 @@ class QuerySendDetailsQueryParams(BaseModel):
         None, title=f"""发送回执ID，即发送流水号。调用发送接口SendSms或SendBatchSms发送短信时，返回值中的BizId字段。"""
     )
 
+    Action: str = Field("QuerySendDetails", title="系统的Action")
+
 
 class SendBatchSmsQueryParams(BaseModel):
     RegionId: Optional[str] = Field(None, title=f"""""")
@@ -102,6 +104,8 @@ class SendBatchSmsQueryParams(BaseModel):
         None, title=f"""上行短信扩展码，JSON数组格式。无特殊需要此字段的用户请忽略此字段。"""
     )
 
+    Action: str = Field("SendBatchSms", title="系统的Action")
+
 
 class SendSmsQueryParams(BaseModel):
     RegionId: Optional[str] = Field(None, title=f"""""")
@@ -155,6 +159,8 @@ class SendSmsQueryParams(BaseModel):
     # 例子: abcdefgh
     OutId: Optional[str] = Field(None, title=f"""外部流水扩展字段。""")
 
+    Action: str = Field("SendSms", title="系统的Action")
+
 
 class AddSmsSignSignFileListField(BaseModel):
     FileSuffix: str
@@ -198,6 +204,8 @@ class AddSmsSignQueryParams(BaseModel):
     # 例子: 155780923770
     OwnerId: Optional[int] = Field(None, title=f"""RAM用户的虚拟账号ID。""")
 
+    Action: str = Field("AddSmsSign", title="系统的Action")
+
 
 class DeleteSmsSignQueryParams(BaseModel):
     RegionId: Optional[str] = Field(None, title=f"""""")
@@ -213,6 +221,8 @@ class DeleteSmsSignQueryParams(BaseModel):
     # 例子: 155780923770
     OwnerId: Optional[int] = Field(None, title=f"""RAM用户的虚拟账号ID。""")
 
+    Action: str = Field("DeleteSmsSign", title="系统的Action")
+
 
 class ModifySmsSignSignFileListField(BaseModel):
     FileSuffix: str
@@ -256,6 +266,8 @@ class ModifySmsSignQueryParams(BaseModel):
     # 例子: 155780923770
     OwnerId: Optional[int] = Field(None, title=f"""RAM用户的虚拟账号ID。""")
 
+    Action: str = Field("ModifySmsSign", title="系统的Action")
+
 
 class AddSmsTemplateQueryParams(BaseModel):
     RegionId: Optional[str] = Field(None, title=f"""""")
@@ -287,6 +299,8 @@ class AddSmsTemplateQueryParams(BaseModel):
     # 例子: 155780923770
     OwnerId: Optional[int] = Field(None, title=f"""RAM用户的虚拟账号ID。""")
 
+    Action: str = Field("AddSmsTemplate", title="系统的Action")
+
 
 class ModifySmsTemplateQueryParams(BaseModel):
     RegionId: Optional[str] = Field(None, title=f"""""")
@@ -303,6 +317,8 @@ class ModifySmsTemplateQueryParams(BaseModel):
 
     OwnerId: Optional[int] = Field(None, title=f"""""")
 
+    Action: str = Field("ModifySmsTemplate", title="系统的Action")
+
 
 class QuerySmsTemplateQueryParams(BaseModel):
     RegionId: Optional[str] = Field(None, title=f"""""")
@@ -311,6 +327,8 @@ class QuerySmsTemplateQueryParams(BaseModel):
 
     OwnerId: Optional[int] = Field(None, title=f"""""")
 
+    Action: str = Field("QuerySmsTemplate", title="系统的Action")
+
 
 class DeleteSmsTemplateQueryParams(BaseModel):
     RegionId: Optional[str] = Field(None, title=f"""""")
@@ -319,6 +337,8 @@ class DeleteSmsTemplateQueryParams(BaseModel):
 
     OwnerId: Optional[int] = Field(None, title=f"""""")
 
+    Action: str = Field("DeleteSmsTemplate", title="系统的Action")
+
 
 class QuerySmsSignQueryParams(BaseModel):
     RegionId: Optional[str] = Field(None, title=f"""""")
@@ -327,12 +347,16 @@ class QuerySmsSignQueryParams(BaseModel):
 
     OwnerId: Optional[int] = Field(None, title=f"""""")
 
+    Action: str = Field("QuerySmsSign", title="系统的Action")
+
 
 class AddShortUrlQueryParams(BaseModel):
     RegionId: Optional[str] = Field(None, title=f"""""")
 
     OwnerId: Optional[int] = Field(None, title=f"""""")
 
+    Action: str = Field("AddShortUrl", title="系统的Action")
+
 
 class AddShortUrlBodyParams(BaseModel):
     SourceUrl: Optional[str] = Field(None, title=f"""""")
@@ -343,42 +367,56 @@ class AddShortUrlBodyParams(BaseModel):
 
     ProdCode: Optional[str] = Field(None, title=f"""""")
 
+    Action: str = Field("AddShortUrl", title="系统的Action")
+
 
 class CreateShortParamQueryParams(BaseModel):
     RegionId: Optional[str] = Field(None, title=f"""""")
 
     OwnerId: Optional[int] = Field(None, title=f"""""")
 
+    Action: str = Field("CreateShortParam", title="系统的Action")
+
 
 class CreateShortParamBodyParams(BaseModel):
     PhoneNumbers: Optional[str] = Field(None, title=f"""""")
 
     ProdCode: Optional[str] = Field(None, title=f"""""")
 
+    Action: str = Field("CreateShortParam", title="系统的Action")
+
 
 class DeleteShortUrlQueryParams(BaseModel):
     RegionId: Optional[str] = Field(None, title=f"""""")
 
     OwnerId: Optional[int] = Field(None, title=f"""""")
 
+    Action: str = Field("DeleteShortUrl", title="系统的Action")
+
 
 class DeleteShortUrlBodyParams(BaseModel):
     SourceUrl: Optional[str] = Field(None, title=f"""""")
 
     ProdCode: Optional[str] = Field(None, title=f"""""")
 
+    Action: str = Field("DeleteShortUrl", title="系统的Action")
+
 
 class QueryShortUrlQueryParams(BaseModel):
     RegionId: Optional[str] = Field(None, title=f"""""")
 
     OwnerId: Optional[int] = Field(None, title=f"""""")
 
+    Action: str = Field("QueryShortUrl", title="系统的Action")
+
 
 class QueryShortUrlBodyParams(BaseModel):
     ProdCode: Optional[str] = Field(None, title=f"""""")
 
     ShortUrl: Optional[str] = Field(None, title=f"""""")
 
+    Action: str = Field("QueryShortUrl", title="系统的Action")
+
 
 class SmsSendDetailDTO(BaseModel):
     PhoneNum: str = Field(..., title=f"""接收短信的手机号码。""")
